@@ -28,8 +28,8 @@ class VersatileImageFieldSerializer(ImageField):
     read_only = True
 
     def __init__(self, sizes, *args, **kwargs):
-        if isinstance(sizes, basestring):
-            sizes = get_rendition_key_set(sizes, validate=False)
+        if isinstance(sizes, str):
+            sizes = get_rendition_key_set(sizes)
         self.sizes = validate_versatileimagefield_sizekey_list(sizes)
         super(VersatileImageFieldSerializer, self).__init__(
             *args, **kwargs
@@ -37,10 +37,17 @@ class VersatileImageFieldSerializer(ImageField):
 
     def to_native(self, value):
         """For djangorestframework <=2.3.14"""
-        return build_versatileimagefield_url_set(value, self.sizes)
+        context_request = None
+        if self.context:
+            context_request = self.context.get('request', None)
+        return build_versatileimagefield_url_set(
+            value,
+            self.sizes,
+            request=context_request
+        )
 
     def to_representation(self, value):
         """
         For djangorestframework >= 3
         """
-        return build_versatileimagefield_url_set(value, self.sizes)
+        return self.to_native(value)
