@@ -1,4 +1,5 @@
-import StringIO
+"""Default sizer & filter definitions."""
+from io import BytesIO
 
 from PIL import Image, ImageOps
 
@@ -12,27 +13,25 @@ class CroppedImage(SizedImage):
 
     See the `process_image` method for more details.
     """
-    filename_key = 'crop'
 
-    def ppoi_as_str(self):
-        return "%s__%s" % (
-            str(self.ppoi[0]).replace('.', '-'),
-            str(self.ppoi[1]).replace('.', '-')
-        )
+    filename_key = 'crop'
+    filename_key_regex = r'crop-c[0-9-]+__[0-9-]+'
 
     def get_filename_key(self):
-        return "%s-c%s" % (
-            self.filename_key,
-            self.ppoi_as_str()
+        """Return the filename key for cropped images."""
+        return "{key}-c{ppoi}".format(
+            key=self.filename_key,
+            ppoi=self.ppoi_as_str()
         )
 
     def crop_on_centerpoint(self, image, width, height, ppoi=(0.5, 0.5)):
         """
-        Returns a PIL Image instance cropped from `image` (at the aspect
-        ratio provided by dividing `width` / `height`), sized down
-        to `width`x`height`. Any 'excess pixels' are trimmed away in respect
-        to the pixel of `image` that corresponds to `ppoi` (Primary Point
-        of Interest).
+        Return a PIL Image instance cropped from `image`.
+
+        Image has an aspect ratio provided by dividing `width` / `height`),
+        sized down to `width`x`height`. Any 'excess pixels' are trimmed away
+        in respect to the pixel of `image` that corresponds to `ppoi` (Primary
+        Point of Interest).
 
         `image`: A PIL Image instance
         `width`: Integer, width of the image to return (in pixels)
@@ -56,7 +55,6 @@ class CroppedImage(SizedImage):
         ppoi value as an absolute centerpoint (as opposed as a
         percentage to trim off the 'long sides').
         """
-
         ppoi_x_axis = int(image.size[0] * ppoi[0])
         ppoi_y_axis = int(image.size[1] * ppoi[1])
         center_pixel_coord = (ppoi_x_axis, ppoi_y_axis)
@@ -78,12 +76,14 @@ class CroppedImage(SizedImage):
             orig_crop_height = image.size[1]
             crop_boundary_top = 0
             crop_boundary_bottom = orig_crop_height
-            crop_boundary_left = center_pixel_coord[0] - (orig_crop_width / 2)
+            crop_boundary_left = center_pixel_coord[0] - (orig_crop_width // 2)
+            crop_boundary_right = crop_boundary_left + orig_crop_width
             if crop_boundary_left < 0:
                 crop_boundary_left = 0
-            crop_boundary_right = crop_boundary_left + orig_crop_width
-            if crop_boundary_right > image.size[0]:
+                crop_boundary_right = crop_boundary_left + orig_crop_width
+            elif crop_boundary_right > image.size[0]:
                 crop_boundary_right = image.size[0]
+                crop_boundary_left = image.size[0] - orig_crop_width
 
         else:
             # `image` is taller than what's needed,
@@ -94,12 +94,14 @@ class CroppedImage(SizedImage):
             )
             crop_boundary_left = 0
             crop_boundary_right = orig_crop_width
-            crop_boundary_top = center_pixel_coord[1] - (orig_crop_height / 2)
+            crop_boundary_top = center_pixel_coord[1] - (orig_crop_height // 2)
+            crop_boundary_bottom = crop_boundary_top + orig_crop_height
             if crop_boundary_top < 0:
                 crop_boundary_top = 0
-            crop_boundary_bottom = crop_boundary_top + orig_crop_height
-            if crop_boundary_bottom > image.size[1]:
+                crop_boundary_bottom = crop_boundary_top + orig_crop_height
+            elif crop_boundary_bottom > image.size[1]:
                 crop_boundary_bottom = image.size[1]
+                crop_boundary_top = image.size[1] - orig_crop_height
         # Cropping the image from the original image
         cropped_image = image.crop(
             (
@@ -119,13 +121,13 @@ class CroppedImage(SizedImage):
     def process_image(self, image, image_format, save_kwargs,
                       width, height):
         """
-        Returns a StringIO instance of `image` cropped to `width` and `height`
+        Return a BytesIO instance of `image` cropped to `width` and `height`.
 
         Cropping will first reduce an image down to its longest side
         and then crop inwards centered on the Primary Point of Interest
         (as specified by `self.ppoi`)
         """
-        imagefile = StringIO.StringIO()
+        imagefile = BytesIO()
         palette = image.getpalette()
         cropped_image = self.crop_on_centerpoint(
             image,
@@ -149,7 +151,7 @@ class CroppedImage(SizedImage):
 
 class ThumbnailImage(SizedImage):
     """
-    Sizes an image down to fit within a bounding box
+    Sizes an image down to fit within a bounding box.
 
     See the `process_image()` method for more information
     """
@@ -159,10 +161,11 @@ class ThumbnailImage(SizedImage):
     def process_image(self, image, image_format, save_kwargs,
                       width, height):
         """
-        Returns a StringIO instance of `image` that will fit
-        within a bounding box as specified by `width`x`height`
+        Return a BytesIO instance of `image` that fits in a bounding box.
+
+        Bounding box dimensions are `width`x`height`.
         """
-        imagefile = StringIO.StringIO()
+        imagefile = BytesIO()
         image.thumbnail(
             (width, height),
             Image.ANTIALIAS
@@ -176,23 +179,22 @@ class ThumbnailImage(SizedImage):
 
 class InvertImage(FilteredImage):
     """
-    Inverts the colors of an image.
+    Invert the color palette of an image.
 
     See the `process_image()` for more specifics
     """
 
     def process_image(self, image, image_format, save_kwargs={}):
-        """
-        Returns a StringIO instance of `image` with inverted colors
-        """
-        imagefile = StringIO.StringIO()
-        inv_image = ImageOps.invert(image)
+        """Return a BytesIO instance of `image` with inverted colors."""
+        imagefile = BytesIO()
+        inv_image = ImageOps.invert(image.convert('RGB'))
         inv_image.save(
             imagefile,
             **save_kwargs
         )
         return imagefile
 
+
 versatileimagefield_registry.register_sizer('crop', CroppedImage)
 versatileimagefield_registry.register_sizer('thumbnail', ThumbnailImage)
 versatileimagefield_registry.register_filter('invert', InvertImage)
